@@ -8,8 +8,12 @@ import org.gcube.portlets.widgets.fileupload.client.view.UploadProgressDialog;
 
 import com.google.gwt.core.client.EntryPoint;
 import com.google.gwt.core.shared.GWT;
+import com.google.gwt.event.dom.client.ClickEvent;
+import com.google.gwt.event.dom.client.ClickHandler;
 import com.google.gwt.event.shared.HandlerManager;
 import com.google.gwt.user.client.Timer;
+import com.google.gwt.user.client.ui.Button;
+import com.google.gwt.user.client.ui.RootPanel;
 /**
  * 
  * @author Massimiliano Assante, ISTI-CNR
@@ -47,7 +51,6 @@ public class FileUpload implements EntryPoint {
 			public void onFileSelected(FileUploadSelectedEvent event) {
 				String fileName = event.getSelectedFileName();
 				GWT.log("selected file name: " + fileName);
-
 				//pretend you do sth with the uploaded file, wait 3 seconds
 				Timer t = new Timer() {
 
